@@ -504,7 +504,7 @@ ref_icon_cell_function (GtkTreeViewColumn *column, GtkCellRenderer *renderer,
 	if (g_hash_table_lookup_extended (self->priv->refs, sha, NULL, NULL))
 		g_object_set (renderer, "stock-id", GTK_STOCK_INFO, NULL);
 	else
-		g_object_set (renderer, "stock-id", "", NULL);
+		g_object_set (renderer, "stock-id", NULL, NULL);
 	
 	g_free (sha);
 }
@@ -992,7 +992,10 @@ git_log_pane_finalize (GObject *object)
 	g_object_unref (self->priv->builder);
 	g_free (self->priv->path);
 	g_hash_table_destroy (self->priv->branches_table);
-	g_hash_table_unref (self->priv->refs);
+
+	if (self->priv->refs)
+		g_hash_table_unref (self->priv->refs);
+
 	g_free (self->priv->selected_branch);
 
 	if (self->priv->active_branch_path != NULL)
